/**
 */
package de.mdelab.mlstorypatterns;

import java.util.Map;
import org.eclipse.emf.common.util.DiagnosticChain;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EStructuralFeature;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>Story Pattern Link</b></em>'. <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * A StoryPatternLink is matched to an instance of EStructuralFeature.
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * </p>
 * <ul>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternLink#getFeature <em>Feature</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternLink#getLinkPositionConstraint <em>Link Position Constraint</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternLink#getOutgoingLinkOrderConstraints <em>Outgoing Link Order Constraints</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternLink#getIncomingLinkOrderConstraints <em>Incoming Link Order Constraints</em>}</li>
 * </ul>
 *
 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternLink()
 * @model annotation="http://www.eclipse.org/emf/2002/Ecore constraints='StoryPatternLinkTargetType'"
 * @generated
 */
public interface StoryPatternLink extends AbstractStoryPatternLink {
	/**
	 * Returns the value of the '<em><b>Feature</b></em>' reference. <!--
	 * begin-user-doc --> <!-- end-user-doc --> <!-- begin-model-doc --> The
	 * EStructuralFeature to match this link to. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Feature</em>' reference.
	 * @see #setFeature(EStructuralFeature)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternLink_Feature()
	 * @model required="true"
	 * @generated
	 */
	EStructuralFeature getFeature();

	/**
	 * Sets the value of the '
	 * {@link de.mdelab.mlstorypatterns.StoryPatternLink#getFeature
	 * <em>Feature</em>}' reference. <!-- begin-user-doc --> <!-- end-user-doc
	 * -->
	 * 
	 * @param value
	 *            the new value of the '<em>Feature</em>' reference.
	 * @see #getFeature()
	 * @generated
	 */
	void setFeature(EStructuralFeature value);

	/**
	 * Returns the value of the '<em><b>Link Position Constraint</b></em>'
	 * attribute. The default value is <code>"UNCONSTRAINED"</code>. The
	 * literals are from the enumeration
	 * {@link de.mdelab.mlstorypatterns.LinkPositionConstraintEnum}. <!--
	 * begin-user-doc --> <!-- end-user-doc --> <!-- begin-model-doc --> In case
	 * the feature is ordered, the link position constraint expresses an
	 * additional constraint on the position of the target object in the link.
	 * <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Link Position Constraint</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.LinkPositionConstraintEnum
	 * @see #setLinkPositionConstraint(LinkPositionConstraintEnum)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternLink_LinkPositionConstraint()
	 * @model default="UNCONSTRAINED" required="true"
	 * @generated
	 */
	LinkPositionConstraintEnum getLinkPositionConstraint();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.StoryPatternLink#getLinkPositionConstraint <em>Link Position Constraint</em>}' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param value the new value of the '<em>Link Position Constraint</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.LinkPositionConstraintEnum
	 * @see #getLinkPositionConstraint()
	 * @generated
	 */
	void setLinkPositionConstraint(LinkPositionConstraintEnum value);

	/**
	 * Returns the value of the '<em><b>Outgoing Link Order Constraints</b></em>
	 * ' reference list. The list contents are of type
	 * {@link de.mdelab.mlstorypatterns.LinkOrderConstraint}. It is
	 * bidirectional and its opposite is '
	 * {@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getPredecessorLink
	 * <em>Predecessor Link</em>}'. <!-- begin-user-doc --> <!-- end-user-doc
	 * --> <!-- begin-model-doc --> The LinkOrderConstraints, for which this
	 * StoryPatternLink is the preceeding link. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Outgoing Link Order Constraints</em>'
	 *         reference list.
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternLink_OutgoingLinkOrderConstraints()
	 * @see de.mdelab.mlstorypatterns.LinkOrderConstraint#getPredecessorLink
	 * @model opposite="predecessorLink" ordered="false"
	 * @generated
	 */
	EList<LinkOrderConstraint> getOutgoingLinkOrderConstraints();

	/**
	 * Returns the value of the '<em><b>Incoming Link Order Constraints</b></em>' reference list.
	 * The list contents are of type {@link de.mdelab.mlstorypatterns.LinkOrderConstraint}.
	 * It is bidirectional and its opposite is '{@link de.mdelab.mlstorypatterns.LinkOrderConstraint#getSuccessorLink <em>Successor Link</em>}'.
	 * <!-- begin-user-doc --> <!-- end-user-doc -->
	 * <!-- begin-model-doc -->
	 * The LinkOrderConstraints, for which this StoryPatternLink is the preceeding link.
	 * <!-- end-model-doc -->
	 * @return the value of the '<em>Incoming Link Order Constraints</em>' reference list.
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternLink_IncomingLinkOrderConstraints()
	 * @see de.mdelab.mlstorypatterns.LinkOrderConstraint#getSuccessorLink
	 * @model opposite="successorLink" resolveProxies="false" ordered="false"
	 *        annotation="http://www.eclipse.org/emf/2002/GenModel get='throw new UnsupportedOperationException();  // FIXME Unimplemented http://www.mdelab.de/mlstorypatterns/1.0!StoryPatternLink!incomingLinkOrderConstraints'"
	 * @generated
	 */
	EList<LinkOrderConstraint> getIncomingLinkOrderConstraints();

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternLinkSourceTypeFeature:\n *   let\n *     severity : Integer[1] = \'StoryPatternLink::StoryPatternLinkSourceTypeFeature\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.source &lt;&gt; null and self.source.type &lt;&gt; null and\n *             self.source.type.oclIsKindOf(ecore::EClass) implies\n *             self.source.type.oclAsType(ecore::EClass)\n *             .eAllStructuralFeatures-&gt;includes(self.feature)\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The feature of story pattern link \' +\n *               self.toString() + \' must belong to its source object\\\'s type.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternLink::StoryPatternLinkSourceTypeFeature\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternLink_c_c_StoryPatternLinkSourceTypeFeature);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\t/*@Caught\052/ /*@NonNull\052/ &lt;%java.lang.Object%&gt; CAUGHT_and;\n\ttry {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternObject%&gt; source_0 = this.getSource();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.emf.ecore.EClassifier%&gt; type_0 = source_0.getType();\n\t\tfinal /*@NonInvalid\052/ boolean ne = type_0 != null;\n\t\t/*@Thrown\052/ boolean and;\n\t\tif (ne) {\n\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_ecore_c_c_EClass_0 = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_EClass, null);\n\t\t\tfinal /*@Thrown\052/ boolean oclIsKindOf = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsKindOfOperation%&gt;.INSTANCE.evaluate(executor, type_0, TYP_ecore_c_c_EClass_0).booleanValue();\n\t\t\tand = oclIsKindOf;\n\t\t}\n\t\telse {\n\t\t\tand = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t\t}\n\t\tCAUGHT_and = and;\n\t}\n\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\tCAUGHT_and = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t}\n\t/*@Caught\052/ /*@NonNull\052/ &lt;%java.lang.Object%&gt; CAUGHT_includes;\n\ttry {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_ecore_c_c_EClass_1 = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_EClass, null);\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternObject%&gt; source_1 = this.getSource();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.emf.ecore.EClassifier%&gt; type_1 = source_1.getType();\n\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.emf.ecore.EClass%&gt; oclAsType = &lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState((&lt;%org.eclipse.emf.ecore.EClass%&gt;)&lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclAsTypeOperation%&gt;.INSTANCE.evaluate(executor, type_1, TYP_ecore_c_c_EClass_1));\n\t\tfinal /*@Thrown\052/ &lt;%java.util.List%&gt;&lt;&lt;%org.eclipse.emf.ecore.EStructuralFeature%&gt;&gt; eAllStructuralFeatures = oclAsType.getEAllStructuralFeatures();\n\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.ocl.pivot.values.OrderedSetValue%&gt; BOXED_eAllStructuralFeatures = idResolver.createOrderedSetOfAll(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ORD_CLSSid_EStructuralFeature, eAllStructuralFeatures);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.emf.ecore.EStructuralFeature%&gt; feature = this.getFeature();\n\t\tfinal /*@Thrown\052/ boolean includes = &lt;%org.eclipse.ocl.pivot.library.collection.CollectionIncludesOperation%&gt;.INSTANCE.evaluate(BOXED_eAllStructuralFeatures, feature).booleanValue();\n\t\tCAUGHT_includes = includes;\n\t}\n\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\tCAUGHT_includes = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t}\n\tfinal /*@Thrown\052/ &lt;%java.lang.Boolean%&gt; implies = &lt;%org.eclipse.ocl.pivot.library.logical.BooleanImpliesOperation%&gt;.INSTANCE.evaluate(CAUGHT_and, CAUGHT_includes);\n\tif (implies == null) {\n\t\tthrow new &lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;(\"Null if condition\");\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_The_32_feature_32_of_32_story_32_pattern_32_link_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_must_32_belong_32_to_32_its_32_source_32_object_39_s_32_type);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternLink_c_c_StoryPatternLinkSourceTypeFeature, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean StoryPatternLinkSourceTypeFeature(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternLinkSourceType:\n *   let\n *     severity : Integer[1] = \'StoryPatternLink::StoryPatternLinkSourceType\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.source &lt;&gt; null and self.source.type &lt;&gt; null implies\n *             self.source.type.oclIsKindOf(ecore::EClass)\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The type of the source of story pattern link \' +\n *               self.toString() + \' must be an EClass.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternLink::StoryPatternLinkSourceType\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternLink_c_c_StoryPatternLinkSourceType);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternObject%&gt; source_0 = this.getSource();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.emf.ecore.EClassifier%&gt; type_0 = source_0.getType();\n\tfinal /*@NonInvalid\052/ boolean ne = type_0 != null;\n\t/*@Thrown\052/ boolean implies;\n\tif (ne) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_ecore_c_c_EClass_0 = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_EClass, null);\n\t\tfinal /*@Thrown\052/ boolean oclIsKindOf = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsKindOfOperation%&gt;.INSTANCE.evaluate(executor, type_0, TYP_ecore_c_c_EClass_0).booleanValue();\n\t\timplies = oclIsKindOf;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_The_32_type_32_of_32_the_32_source_32_of_32_story_32_pattern_32_link_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_must_32_be_32_an_32_EClass);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternLink_c_c_StoryPatternLinkSourceType, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean StoryPatternLinkSourceType(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternLinkOrderedFeature:\n *   let\n *     severity : Integer[1] = \'StoryPatternLink::StoryPatternLinkOrderedFeature\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.linkPositionConstraint &lt;&gt; LinkPositionConstraintEnum::UNCONSTRAINED and self.feature &lt;&gt; null implies self.feature.ordered\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The feature of story pattern link \' +\n *               self.toString() + \' with a link position constraint must be ordered.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternLink::StoryPatternLinkOrderedFeature\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternLink_c_c_StoryPatternLinkOrderedFeature);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.LinkPositionConstraintEnum%&gt; linkPositionConstraint = this.getLinkPositionConstraint();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_linkPositionConstraint = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_LinkPositionConstraintEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(linkPositionConstraint.getName()));\n\tfinal /*@NonInvalid\052/ boolean ne = BOXED_linkPositionConstraint != &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_UNCONSTRAINED;\n\t/*@NonInvalid\052/ boolean and;\n\tif (ne) {\n\t\tand = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tand = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t}\n\t/*@NonInvalid\052/ boolean implies;\n\tif (and) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.emf.ecore.EStructuralFeature%&gt; feature = this.getFeature();\n\t\tfinal /*@NonInvalid\052/ boolean ordered = feature.isOrdered();\n\t\timplies = ordered;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_The_32_feature_32_of_32_story_32_pattern_32_link_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_with_32_a_32_link_32_position_32_constraint_32_must_32_be_32_ordered);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternLink_c_c_StoryPatternLinkOrderedFeature, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean StoryPatternLinkOrderedFeature(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternLinkFeature:\n *   let\n *     severity : Integer[1] = \'StoryPatternLink::StoryPatternLinkFeature\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.feature &lt;&gt; null\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Feature of story pattern link \' +\n *               self.toString() + \' must be specified.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternLink::StoryPatternLinkFeature\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternLink_c_c_StoryPatternLinkFeature);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_0;\nif (le) {\n\tsymbol_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternLink_c_c_StoryPatternLinkFeature, this, (Object)null, diagnostics, context, (Object)null, severity_0, &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_0 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_0;'"
	 * @generated
	 */
	boolean StoryPatternLinkFeature(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternLinkPositionConstraint:\n *   let\n *     severity : Integer[1] = \'StoryPatternLink::StoryPatternLinkPositionConstraint\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.linkPositionConstraint &lt;&gt; null\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Link position constraint of story pattern link \' +\n *               self.toString() + \' must be specified. For unconstrained links use literal \\\'UNCONSTRAINED\\\'.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternLink::StoryPatternLinkPositionConstraint\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternLink_c_c_StoryPatternLinkPositionConstraint);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_0;\nif (le) {\n\tsymbol_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternLink_c_c_StoryPatternLinkPositionConstraint, this, (Object)null, diagnostics, context, (Object)null, severity_0, &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_0 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_0;'"
	 * @generated
	 */
	boolean StoryPatternLinkPositionConstraint(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternLinkTargetType:\n *   let\n *     severity : Integer[1] = \'StoryPatternLink::StoryPatternLinkTargetType\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.target &lt;&gt; null and self.target.type &lt;&gt; null implies self.feature.eType = self.target.type or\n *             self.target.type.oclIsKindOf(ecore::EClass) and\n *             (\n *               self.target.type.oclAsType(ecore::EClass)\n *               .eAllSuperTypes-&gt;includes(self.feature.eType) or self.feature.eType.name = \'EObject\'\n *             )\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'The type of the target of story pattern link \' +\n *               self.toString() + \' must match its feature\\\'s type.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternLink::StoryPatternLinkTargetType\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternLink_c_c_StoryPatternLinkTargetType);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternObject%&gt; target = this.getTarget();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.emf.ecore.EClassifier%&gt; type = target.getType();\n\tfinal /*@NonInvalid\052/ boolean ne = type != null;\n\t/*@Thrown\052/ &lt;%java.lang.Boolean%&gt; implies;\n\tif (ne) {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.emf.ecore.EStructuralFeature%&gt; feature = this.getFeature();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.emf.ecore.EClassifier%&gt; eType = feature.getEType();\n\t\tfinal /*@NonInvalid\052/ boolean eq = (eType != null) ? eType.equals(type) : (type == null);\n\t\t/*@Thrown\052/ &lt;%java.lang.Boolean%&gt; or_0;\n\t\tif (eq) {\n\t\t\tor_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t\t}\n\t\telse {\n\t\t\t/*@Caught\052/ /*@NonNull\052/ &lt;%java.lang.Object%&gt; CAUGHT_oclIsKindOf;\n\t\t\ttry {\n\t\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_ecore_c_c_EClass_0 = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_EClass, null);\n\t\t\t\tfinal /*@Thrown\052/ boolean oclIsKindOf = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsKindOfOperation%&gt;.INSTANCE.evaluate(executor, type, TYP_ecore_c_c_EClass_0).booleanValue();\n\t\t\t\tCAUGHT_oclIsKindOf = oclIsKindOf;\n\t\t\t}\n\t\t\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\t\t\tCAUGHT_oclIsKindOf = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t\t\t}\n\t\t\t/*@Caught\052/ /*@Nullable\052/ &lt;%java.lang.Object%&gt; CAUGHT_or;\n\t\t\ttry {\n\t\t\t\t/*@Caught\052/ /*@NonNull\052/ &lt;%java.lang.Object%&gt; CAUGHT_includes;\n\t\t\t\ttry {\n\t\t\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_ecore_c_c_EClass_1 = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_EClass, null);\n\t\t\t\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.emf.ecore.EClass%&gt; oclAsType = &lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState((&lt;%org.eclipse.emf.ecore.EClass%&gt;)&lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclAsTypeOperation%&gt;.INSTANCE.evaluate(executor, type, TYP_ecore_c_c_EClass_1));\n\t\t\t\t\tfinal /*@Thrown\052/ &lt;%java.util.List%&gt;&lt;&lt;%org.eclipse.emf.ecore.EClass%&gt;&gt; eAllSuperTypes = oclAsType.getEAllSuperTypes();\n\t\t\t\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.ocl.pivot.values.OrderedSetValue%&gt; BOXED_eAllSuperTypes = idResolver.createOrderedSetOfAll(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ORD_CLSSid_EClass, eAllSuperTypes);\n\t\t\t\t\tfinal /*@Thrown\052/ boolean includes = &lt;%org.eclipse.ocl.pivot.library.collection.CollectionIncludesOperation%&gt;.INSTANCE.evaluate(BOXED_eAllSuperTypes, eType).booleanValue();\n\t\t\t\t\tCAUGHT_includes = includes;\n\t\t\t\t}\n\t\t\t\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\t\t\t\tCAUGHT_includes = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t\t\t\t}\n\t\t\t\t/*@Caught\052/ /*@NonNull\052/ &lt;%java.lang.Object%&gt; CAUGHT_eq_0;\n\t\t\t\ttry {\n\t\t\t\t\tif (eType == null) {\n\t\t\t\t\t\tthrow new &lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;(\"Null source for \\\'\\\'http://www.eclipse.org/emf/2002/Ecore\\\'::ENamedElement::name\\\'\");\n\t\t\t\t\t}\n\t\t\t\t\tfinal /*@Thrown\052/ &lt;%java.lang.String%&gt; name = eType.getName();\n\t\t\t\t\tfinal /*@Thrown\052/ boolean eq_0 = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_EObject.equals(name);\n\t\t\t\t\tCAUGHT_eq_0 = eq_0;\n\t\t\t\t}\n\t\t\t\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\t\t\t\tCAUGHT_eq_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t\t\t\t}\n\t\t\t\tfinal /*@Thrown\052/ &lt;%java.lang.Boolean%&gt; or = &lt;%org.eclipse.ocl.pivot.library.logical.BooleanOrOperation%&gt;.INSTANCE.evaluate(CAUGHT_includes, CAUGHT_eq_0);\n\t\t\t\tCAUGHT_or = or;\n\t\t\t}\n\t\t\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\t\t\tCAUGHT_or = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t\t\t}\n\t\t\tfinal /*@Thrown\052/ &lt;%java.lang.Boolean%&gt; and = &lt;%org.eclipse.ocl.pivot.library.logical.BooleanAndOperation%&gt;.INSTANCE.evaluate(CAUGHT_oclIsKindOf, CAUGHT_or);\n\t\t\tor_0 = and;\n\t\t}\n\t\timplies = or_0;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\tif (implies == null) {\n\t\tthrow new &lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;(\"Null if condition\");\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_The_32_type_32_of_32_the_32_target_32_of_32_story_32_pattern_32_link_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_must_32_match_32_its_32_feature_39_s_32_type);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternLink_c_c_StoryPatternLinkTargetType, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean StoryPatternLinkTargetType(DiagnosticChain diagnostics,
			Map<Object, Object> context);

} // StoryPatternLink
