/**
 */
package de.mdelab.mlstorypatterns;

import org.eclipse.emf.common.util.EList;

import de.mdelab.mlexpressions.MLExpression;
import java.util.Map;
import org.eclipse.emf.common.util.DiagnosticChain;

/**
 * <!-- begin-user-doc --> A representation of the model object '
 * <em><b>Story Pattern Object</b></em>'. <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * A StoryPatternObject is matched to an EObject, when the StoryPattern is executed.
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * </p>
 * <ul>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternObject#getBindingType <em>Binding Type</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternObject#getConstraints <em>Constraints</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternObject#getAssignmentExpression <em>Assignment Expression</em>}</li>
 *   <li>{@link de.mdelab.mlstorypatterns.StoryPatternObject#getAttributeAssignments <em>Attribute Assignments</em>}</li>
 * </ul>
 *
 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternObject()
 * @model annotation="http://www.eclipse.org/emf/2002/Ecore constraints='StoryPatternObjectNACUnbound'"
 * @generated
 */
public interface StoryPatternObject extends AbstractStoryPatternObject {
	/**
	 * Returns the value of the '<em><b>Binding Type</b></em>' attribute. The
	 * literals are from the enumeration
	 * {@link de.mdelab.mlstorypatterns.BindingTypeEnum}. <!-- begin-user-doc
	 * --> <!-- end-user-doc --> <!-- begin-model-doc --> The binding type
	 * specifies, whether an existing binding is used for this object or a new
	 * match has to be sought. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Binding Type</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.BindingTypeEnum
	 * @see #setBindingType(BindingTypeEnum)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternObject_BindingType()
	 * @model required="true"
	 * @generated
	 */
	BindingTypeEnum getBindingType();

	/**
	 * Sets the value of the '{@link de.mdelab.mlstorypatterns.StoryPatternObject#getBindingType <em>Binding Type</em>}' attribute.
	 * <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * @param value the new value of the '<em>Binding Type</em>' attribute.
	 * @see de.mdelab.mlstorypatterns.BindingTypeEnum
	 * @see #getBindingType()
	 * @generated
	 */
	void setBindingType(BindingTypeEnum value);

	/**
	 * Returns the value of the '<em><b>Constraints</b></em>' containment
	 * reference list. The list contents are of type
	 * {@link de.mdelab.mlexpressions.MLExpression}. <!-- begin-user-doc -->
	 * <!-- end-user-doc --> <!-- begin-model-doc --> Constraints express
	 * additional conditions that have to be fulfilled to match this object.
	 * <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Constraints</em>' containment reference
	 *         list.
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternObject_Constraints()
	 * @model containment="true" ordered="false"
	 * @generated
	 */
	EList<MLExpression> getConstraints();

	/**
	 * Returns the value of the '<em><b>Assignment Expression</b></em>'
	 * containment reference. <!-- begin-user-doc --> <!-- end-user-doc --> <!--
	 * begin-model-doc --> An assignment expression has to return an object to
	 * which the StoryPatternObject is matched. The StoryPatternObject's binding
	 * type has to be 'BOUND'. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Assignment Expression</em>' containment
	 *         reference.
	 * @see #setAssignmentExpression(MLExpression)
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternObject_AssignmentExpression()
	 * @model containment="true"
	 * @generated
	 */
	MLExpression getAssignmentExpression();

	/**
	 * Sets the value of the '
	 * {@link de.mdelab.mlstorypatterns.StoryPatternObject#getAssignmentExpression
	 * <em>Assignment Expression</em>}' containment reference. <!--
	 * begin-user-doc --> <!-- end-user-doc -->
	 * 
	 * @param value
	 *            the new value of the '<em>Assignment Expression</em>'
	 *            containment reference.
	 * @see #getAssignmentExpression()
	 * @generated
	 */
	void setAssignmentExpression(MLExpression value);

	/**
	 * Returns the value of the '<em><b>Attribute Assignments</b></em>'
	 * containment reference list. The list contents are of type
	 * {@link de.mdelab.mlstorypatterns.AttributeAssignment}. It is
	 * bidirectional and its opposite is '
	 * {@link de.mdelab.mlstorypatterns.AttributeAssignment#getStoryPatternObject
	 * <em>Story Pattern Object</em>}'. <!-- begin-user-doc --> <!--
	 * end-user-doc --> <!-- begin-model-doc --> Attribute assignments specify
	 * attribute values to set when the StoryPattern is applied. Attribute
	 * assignments are evaluated after matching the pattern but before applying
	 * it. <!-- end-model-doc -->
	 * 
	 * @return the value of the '<em>Attribute Assignments</em>' containment
	 *         reference list.
	 * @see de.mdelab.mlstorypatterns.MlstorypatternsPackage#getStoryPatternObject_AttributeAssignments()
	 * @see de.mdelab.mlstorypatterns.AttributeAssignment#getStoryPatternObject
	 * @model opposite="storyPatternObject" containment="true" ordered="false"
	 * @generated
	 */
	EList<AttributeAssignment> getAttributeAssignments();

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternObjectAssignmentBound:\n *   let\n *     severity : Integer[1] = \'StoryPatternObject::StoryPatternObjectAssignmentBound\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.assignmentExpression &lt;&gt; null implies self.bindingType = BindingTypeEnum::BOUND\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Story pattern object \' +\n *               self.toString() + \' with assignment expression must be bound.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternObject::StoryPatternObjectAssignmentBound\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectAssignmentBound);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlexpressions.MLExpression%&gt; assignmentExpression = this.getAssignmentExpression();\n\tfinal /*@NonInvalid\052/ boolean ne = assignmentExpression != null;\n\t/*@NonInvalid\052/ boolean implies;\n\tif (ne) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.BindingTypeEnum%&gt; bindingType = this.getBindingType();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_bindingType = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_BindingTypeEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(bindingType.getName()));\n\t\tfinal /*@NonInvalid\052/ boolean eq = BOXED_bindingType == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_BOUND;\n\t\timplies = eq;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Story_32_pattern_32_object_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_with_32_assignment_32_expression_32_must_32_be_32_bound);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectAssignmentBound, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean StoryPatternObjectAssignmentBound(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternObjectDataType:\n *   let\n *     severity : Integer[1] = \'StoryPatternObject::StoryPatternObjectDataType\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if\n *             self.type.oclIsKindOf(ecore::EDataType) implies\n *             self.attributeAssignments-&gt;isEmpty()\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Story pattern object \' +\n *               self.toString() + \', whose type is an EDataType, may not have attribute assignments.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternObject::StoryPatternObjectDataType\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectDataType);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\t/*@Caught\052/ /*@NonNull\052/ &lt;%java.lang.Object%&gt; CAUGHT_oclIsKindOf;\n\ttry {\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_ecore_c_c_EDataType = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_EDataType, null);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.emf.ecore.EClassifier%&gt; type = this.getType();\n\t\tfinal /*@Thrown\052/ boolean oclIsKindOf = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsKindOfOperation%&gt;.INSTANCE.evaluate(executor, type, TYP_ecore_c_c_EDataType).booleanValue();\n\t\tCAUGHT_oclIsKindOf = oclIsKindOf;\n\t}\n\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\tCAUGHT_oclIsKindOf = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t}\n\tfinal /*@NonInvalid\052/ &lt;%java.util.List%&gt;&lt;&lt;%de.mdelab.mlstorypatterns.AttributeAssignment%&gt;&gt; attributeAssignments = this.getAttributeAssignments();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.SetValue%&gt; BOXED_attributeAssignments = idResolver.createSetOfAll(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.SET_CLSSid_AttributeAssignment, attributeAssignments);\n\tfinal /*@NonInvalid\052/ boolean isEmpty = &lt;%org.eclipse.ocl.pivot.library.collection.CollectionIsEmptyOperation%&gt;.INSTANCE.evaluate(BOXED_attributeAssignments).booleanValue();\n\tfinal /*@Thrown\052/ &lt;%java.lang.Boolean%&gt; implies = &lt;%org.eclipse.ocl.pivot.library.logical.BooleanImpliesOperation%&gt;.INSTANCE.evaluate(CAUGHT_oclIsKindOf, isEmpty);\n\tif (implies == null) {\n\t\tthrow new &lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;(\"Null if condition\");\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Story_32_pattern_32_object_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__44_32_whose_32_type_32_is_32_an_32_EDataType_44_32_may_32_not_32_have_32_attribute_32_assignments);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectDataType, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean StoryPatternObjectDataType(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternObjectIncomingLink:\n *   let\n *     severity : Integer[1] = \'StoryPatternObject::StoryPatternObjectIncomingLink\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.bindingType &lt;&gt; BindingTypeEnum::BOUND and self.modifier &lt;&gt; ModifierEnum::CREATE and self.matchType = MatchTypeEnum::DEFAULT implies\n *             self.incomingLinks-&gt;exists(e | e.modifier &lt;&gt; null) or\n *             self.outgoingLinks-&gt;exists(e | e.modifier &lt;&gt; ModifierEnum::CREATE and\n *               (\n *                 e.oclIsKindOf(ContainmentLink) or\n *                 e.oclIsKindOf(StoryPatternLink) and\n *                 e.oclAsType(StoryPatternLink)\n *                 .feature.oclIsKindOf(ecore::EReference) and\n *                 (\n *                   e.oclAsType(StoryPatternLink)\n *                   .feature.oclAsType(ecore::EReference).eOpposite &lt;&gt; null or\n *                   e.oclAsType(StoryPatternLink)\n *                   .feature.oclAsType(ecore::EReference).containment\n *                 )\n *               )) or\n *             self.storyPattern.storyPatternLinks-&gt;exists(e |\n *               e.oclIsKindOf(MapEntryLink) and\n *               e.oclAsType(MapEntryLink).valueTarget = self)\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Story pattern object \' +\n *               self.toString() + \' must be reacheable from another object.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternObject::StoryPatternObjectIncomingLink\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectIncomingLink);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.BindingTypeEnum%&gt; bindingType = this.getBindingType();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_bindingType = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_BindingTypeEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(bindingType.getName()));\n\tfinal /*@NonInvalid\052/ boolean ne = BOXED_bindingType != &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_BOUND;\n\t/*@NonInvalid\052/ boolean and;\n\tif (ne) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier = this.getModifier();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier.getName()));\n\t\tfinal /*@NonInvalid\052/ boolean ne_0 = BOXED_modifier != &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_CREATE;\n\t\tand = ne_0;\n\t}\n\telse {\n\t\tand = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t}\n\t/*@NonInvalid\052/ boolean and_0;\n\tif (and) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.MatchTypeEnum%&gt; matchType = this.getMatchType();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_matchType = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_MatchTypeEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(matchType.getName()));\n\t\tfinal /*@NonInvalid\052/ boolean eq = BOXED_matchType == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_DEFAULT;\n\t\tand_0 = eq;\n\t}\n\telse {\n\t\tand_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t}\n\t/*@Thrown\052/ &lt;%java.lang.Boolean%&gt; implies;\n\tif (and_0) {\n\t\t/*@Caught\052/ /*@Nullable\052/ &lt;%java.lang.Object%&gt; CAUGHT_or_1;\n\t\ttry {\n\t\t\tfinal /*@NonInvalid\052/ &lt;%java.util.List%&gt;&lt;&lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternLink%&gt;&gt; incomingLinks = this.getIncomingLinks();\n\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.SetValue%&gt; BOXED_incomingLinks = idResolver.createSetOfAll(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.SET_CLSSid_AbstractStoryPatternLink, incomingLinks);\n\t\t\t/*@Thrown\052/ &lt;%java.lang.Object%&gt; accumulator = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t\t\t/*@NonNull\052/ &lt;%java.util.Iterator%&gt;&lt;&lt;%java.lang.Object%&gt;&gt; ITERATOR_e_0 = BOXED_incomingLinks.iterator();\n\t\t\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; exists;\n\t\t\twhile (true) {\n\t\t\t\tif (!ITERATOR_e_0.hasNext()) {\n\t\t\t\t\tif (accumulator == &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE) {\n\t\t\t\t\t\texists = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t\t\t\t\t}\n\t\t\t\t\telse {\n\t\t\t\t\t\tthrow (&lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;)accumulator;\n\t\t\t\t\t}\n\t\t\t\t\tbreak;\n\t\t\t\t}\n\t\t\t\t/*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternLink%&gt; e_0 = (&lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternLink%&gt;)ITERATOR_e_0.next();\n\t\t\t\t/**\n\t\t\t\t * e.modifier &lt;&gt; null\n\t\t\t\t \052/\n\t\t\t\t//\n\t\t\t\texists = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t\t\t\tbreak;\n\t\t\t}\n\t\t\t/*@Caught\052/ /*@Nullable\052/ &lt;%java.lang.Object%&gt; CAUGHT_exists_0;\n\t\t\ttry {\n\t\t\t\tfinal /*@NonInvalid\052/ &lt;%java.util.List%&gt;&lt;&lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternLink%&gt;&gt; outgoingLinks = this.getOutgoingLinks();\n\t\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.SetValue%&gt; BOXED_outgoingLinks = idResolver.createSetOfAll(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.SET_CLSSid_AbstractStoryPatternLink, outgoingLinks);\n\t\t\t\t/*@Thrown\052/ &lt;%java.lang.Object%&gt; accumulator_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t\t\t\t/*@NonNull\052/ &lt;%java.util.Iterator%&gt;&lt;&lt;%java.lang.Object%&gt;&gt; ITERATOR_e_1 = BOXED_outgoingLinks.iterator();\n\t\t\t\t/*@Thrown\052/ &lt;%java.lang.Boolean%&gt; exists_0;\n\t\t\t\twhile (true) {\n\t\t\t\t\tif (!ITERATOR_e_1.hasNext()) {\n\t\t\t\t\t\tif (accumulator_0 == null) {\n\t\t\t\t\t\t\texists_0 = null;\n\t\t\t\t\t\t}\n\t\t\t\t\t\telse if (accumulator_0 == &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE) {\n\t\t\t\t\t\t\texists_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t\t\t\t\t\t}\n\t\t\t\t\t\telse {\n\t\t\t\t\t\t\tthrow (&lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;)accumulator_0;\n\t\t\t\t\t\t}\n\t\t\t\t\t\tbreak;\n\t\t\t\t\t}\n\t\t\t\t\t/*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternLink%&gt; e_1 = (&lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternLink%&gt;)ITERATOR_e_1.next();\n\t\t\t\t\t/**\n\t\t\t\t\t * e.modifier &lt;&gt; ModifierEnum::CREATE and\n\t\t\t\t\t * (\n\t\t\t\t\t *   e.oclIsKindOf(ContainmentLink) or\n\t\t\t\t\t *   e.oclIsKindOf(StoryPatternLink) and\n\t\t\t\t\t *   e.oclAsType(StoryPatternLink)\n\t\t\t\t\t *   .feature.oclIsKindOf(ecore::EReference) and\n\t\t\t\t\t *   (\n\t\t\t\t\t *     e.oclAsType(StoryPatternLink)\n\t\t\t\t\t *     .feature.oclAsType(ecore::EReference).eOpposite &lt;&gt; null or\n\t\t\t\t\t *     e.oclAsType(StoryPatternLink)\n\t\t\t\t\t *     .feature.oclAsType(ecore::EReference).containment\n\t\t\t\t\t *   )\n\t\t\t\t\t * )\n\t\t\t\t\t \052/\n\t\t\t\t\t/*@Caught\052/ /*@Nullable\052/ &lt;%java.lang.Object%&gt; CAUGHT_and_3;\n\t\t\t\t\ttry {\n\t\t\t\t\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier_0 = e_1.getModifier();\n\t\t\t\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier_0 = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier_0.getName()));\n\t\t\t\t\t\tfinal /*@NonInvalid\052/ boolean ne_1 = BOXED_modifier_0 != &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_CREATE;\n\t\t\t\t\t\t/*@Thrown\052/ &lt;%java.lang.Boolean%&gt; and_3;\n\t\t\t\t\t\tif (ne_1) {\n\t\t\t\t\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlstorypatterns_c_c_ContainmentLink = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_ContainmentLink, null);\n\t\t\t\t\t\t\tfinal /*@NonInvalid\052/ boolean oclIsKindOf = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsKindOfOperation%&gt;.INSTANCE.evaluate(executor, e_1, TYP_mlstorypatterns_c_c_ContainmentLink).booleanValue();\n\t\t\t\t\t\t\t/*@Thrown\052/ &lt;%java.lang.Boolean%&gt; or_0;\n\t\t\t\t\t\t\tif (oclIsKindOf) {\n\t\t\t\t\t\t\t\tor_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\telse {\n\t\t\t\t\t\t\t\t/*@Caught\052/ /*@NonNull\052/ &lt;%java.lang.Object%&gt; CAUGHT_and_1;\n\t\t\t\t\t\t\t\ttry {\n\t\t\t\t\t\t\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlstorypatterns_c_c_StoryPatternLink = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_StoryPatternLink, null);\n\t\t\t\t\t\t\t\t\tfinal /*@NonInvalid\052/ boolean oclIsKindOf_0 = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsKindOfOperation%&gt;.INSTANCE.evaluate(executor, e_1, TYP_mlstorypatterns_c_c_StoryPatternLink).booleanValue();\n\t\t\t\t\t\t\t\t\t/*@Thrown\052/ boolean and_1;\n\t\t\t\t\t\t\t\t\tif (oclIsKindOf_0) {\n\t\t\t\t\t\t\t\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_ecore_c_c_EReference = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_EReference, null);\n\t\t\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ &lt;%de.mdelab.mlstorypatterns.StoryPatternLink%&gt; oclAsType = &lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState((&lt;%de.mdelab.mlstorypatterns.StoryPatternLink%&gt;)&lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclAsTypeOperation%&gt;.INSTANCE.evaluate(executor, e_1, TYP_mlstorypatterns_c_c_StoryPatternLink));\n\t\t\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.emf.ecore.EStructuralFeature%&gt; feature = oclAsType.getFeature();\n\t\t\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ boolean oclIsKindOf_1 = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsKindOfOperation%&gt;.INSTANCE.evaluate(executor, feature, TYP_ecore_c_c_EReference).booleanValue();\n\t\t\t\t\t\t\t\t\t\tand_1 = oclIsKindOf_1;\n\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t\telse {\n\t\t\t\t\t\t\t\t\t\tand_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t\tCAUGHT_and_1 = and_1;\n\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\t\t\t\t\t\t\t\tCAUGHT_and_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t/*@Caught\052/ /*@Nullable\052/ &lt;%java.lang.Object%&gt; CAUGHT_or;\n\t\t\t\t\t\t\t\ttry {\n\t\t\t\t\t\t\t\t\t/*@Caught\052/ /*@NonNull\052/ &lt;%java.lang.Object%&gt; CAUGHT_ne_2;\n\t\t\t\t\t\t\t\t\ttry {\n\t\t\t\t\t\t\t\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_ecore_c_c_EReference_0 = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_EReference, null);\n\t\t\t\t\t\t\t\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlstorypatterns_c_c_StoryPatternLink_1 = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_StoryPatternLink, null);\n\t\t\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ &lt;%de.mdelab.mlstorypatterns.StoryPatternLink%&gt; oclAsType_0 = &lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState((&lt;%de.mdelab.mlstorypatterns.StoryPatternLink%&gt;)&lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclAsTypeOperation%&gt;.INSTANCE.evaluate(executor, e_1, TYP_mlstorypatterns_c_c_StoryPatternLink_1));\n\t\t\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.emf.ecore.EStructuralFeature%&gt; feature_0 = oclAsType_0.getFeature();\n\t\t\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.emf.ecore.EReference%&gt; oclAsType_1 = &lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState((&lt;%org.eclipse.emf.ecore.EReference%&gt;)&lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclAsTypeOperation%&gt;.INSTANCE.evaluate(executor, feature_0, TYP_ecore_c_c_EReference_0));\n\t\t\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.emf.ecore.EReference%&gt; eOpposite = oclAsType_1.getEOpposite();\n\t\t\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ boolean ne_2 = eOpposite != null;\n\t\t\t\t\t\t\t\t\t\tCAUGHT_ne_2 = ne_2;\n\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\t\t\t\t\t\t\t\t\tCAUGHT_ne_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t\t/*@Caught\052/ /*@NonNull\052/ &lt;%java.lang.Object%&gt; CAUGHT_containment;\n\t\t\t\t\t\t\t\t\ttry {\n\t\t\t\t\t\t\t\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_ecore_c_c_EReference_1 = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_EReference, null);\n\t\t\t\t\t\t\t\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlstorypatterns_c_c_StoryPatternLink_2 = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_StoryPatternLink, null);\n\t\t\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ &lt;%de.mdelab.mlstorypatterns.StoryPatternLink%&gt; oclAsType_2 = &lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState((&lt;%de.mdelab.mlstorypatterns.StoryPatternLink%&gt;)&lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclAsTypeOperation%&gt;.INSTANCE.evaluate(executor, e_1, TYP_mlstorypatterns_c_c_StoryPatternLink_2));\n\t\t\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.emf.ecore.EStructuralFeature%&gt; feature_1 = oclAsType_2.getFeature();\n\t\t\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ &lt;%org.eclipse.emf.ecore.EReference%&gt; oclAsType_3 = &lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState((&lt;%org.eclipse.emf.ecore.EReference%&gt;)&lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclAsTypeOperation%&gt;.INSTANCE.evaluate(executor, feature_1, TYP_ecore_c_c_EReference_1));\n\t\t\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ boolean containment = oclAsType_3.isContainment();\n\t\t\t\t\t\t\t\t\t\tCAUGHT_containment = containment;\n\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\t\t\t\t\t\t\t\t\tCAUGHT_containment = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ &lt;%java.lang.Boolean%&gt; or = &lt;%org.eclipse.ocl.pivot.library.logical.BooleanOrOperation%&gt;.INSTANCE.evaluate(CAUGHT_ne_2, CAUGHT_containment);\n\t\t\t\t\t\t\t\t\tCAUGHT_or = or;\n\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\t\t\t\t\t\t\t\tCAUGHT_or = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\t\tfinal /*@Thrown\052/ &lt;%java.lang.Boolean%&gt; and_2 = &lt;%org.eclipse.ocl.pivot.library.logical.BooleanAndOperation%&gt;.INSTANCE.evaluate(CAUGHT_and_1, CAUGHT_or);\n\t\t\t\t\t\t\t\tor_0 = and_2;\n\t\t\t\t\t\t\t}\n\t\t\t\t\t\t\tand_3 = or_0;\n\t\t\t\t\t\t}\n\t\t\t\t\t\telse {\n\t\t\t\t\t\t\tand_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t\t\t\t\t\t}\n\t\t\t\t\t\tCAUGHT_and_3 = and_3;\n\t\t\t\t\t}\n\t\t\t\t\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\t\t\t\t\tCAUGHT_and_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t\t\t\t\t}\n\t\t\t\t\t//\n\t\t\t\t\tif (CAUGHT_and_3 == &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE) {\t\t\t\t\t// Normal successful body evaluation result\n\t\t\t\t\t\texists_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t\t\t\t\t\tbreak;\t\t\t\t\t\t\t\t\t\t\t\t\t\t// Stop immediately\n\t\t\t\t\t}\n\t\t\t\t\telse if (CAUGHT_and_3 == &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE) {\t\t\t\t// Normal unsuccessful body evaluation result\n\t\t\t\t\t\t;\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t// Carry on\n\t\t\t\t\t}\n\t\t\t\t\telse if (CAUGHT_and_3 == null) {\t\t\t\t\t\t\t\t// Abnormal null body evaluation result\n\t\t\t\t\t\tif (accumulator_0 == &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE) {\n\t\t\t\t\t\t\taccumulator_0 = null;\t\t\t\t\t\t\t\t\t\t// Cache a null failure\n\t\t\t\t\t\t}\n\t\t\t\t\t}\n\t\t\t\t\telse if (CAUGHT_and_3 instanceof &lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;) {\t\t// Abnormal exception evaluation result\n\t\t\t\t\t\taccumulator_0 = CAUGHT_and_3;\t\t\t\t\t\t\t\t\t// Cache an exception failure\n\t\t\t\t\t}\n\t\t\t\t\telse {\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t// Impossible badly typed result\n\t\t\t\t\t\taccumulator_0 = new &lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;(&lt;%org.eclipse.ocl.pivot.messages.PivotMessages%&gt;.NonBooleanBody, \"exists\");\n\t\t\t\t\t}\n\t\t\t\t}\n\t\t\t\tCAUGHT_exists_0 = exists_0;\n\t\t\t}\n\t\t\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\t\t\tCAUGHT_exists_0 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t\t\t}\n\t\t\tfinal /*@Thrown\052/ &lt;%java.lang.Boolean%&gt; or_1 = &lt;%org.eclipse.ocl.pivot.library.logical.BooleanOrOperation%&gt;.INSTANCE.evaluate(exists, CAUGHT_exists_0);\n\t\t\tCAUGHT_or_1 = or_1;\n\t\t}\n\t\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\t\tCAUGHT_or_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t\t}\n\t\t/*@Caught\052/ /*@Nullable\052/ &lt;%java.lang.Object%&gt; CAUGHT_exists_1;\n\t\ttry {\n\t\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPattern%&gt; storyPattern = this.getStoryPattern();\n\t\t\tfinal /*@NonInvalid\052/ &lt;%java.util.List%&gt;&lt;&lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternLink%&gt;&gt; storyPatternLinks = storyPattern.getStoryPatternLinks();\n\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.SetValue%&gt; BOXED_storyPatternLinks = idResolver.createSetOfAll(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.SET_CLSSid_AbstractStoryPatternLink, storyPatternLinks);\n\t\t\t/*@Thrown\052/ &lt;%java.lang.Object%&gt; accumulator_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t\t\t/*@NonNull\052/ &lt;%java.util.Iterator%&gt;&lt;&lt;%java.lang.Object%&gt;&gt; ITERATOR_e_2 = BOXED_storyPatternLinks.iterator();\n\t\t\t/*@Thrown\052/ &lt;%java.lang.Boolean%&gt; exists_1;\n\t\t\twhile (true) {\n\t\t\t\tif (!ITERATOR_e_2.hasNext()) {\n\t\t\t\t\tif (accumulator_1 == &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE) {\n\t\t\t\t\t\texists_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t\t\t\t\t}\n\t\t\t\t\telse {\n\t\t\t\t\t\tthrow (&lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;)accumulator_1;\n\t\t\t\t\t}\n\t\t\t\t\tbreak;\n\t\t\t\t}\n\t\t\t\t/*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternLink%&gt; e_2 = (&lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternLink%&gt;)ITERATOR_e_2.next();\n\t\t\t\t/**\n\t\t\t\t *\n\t\t\t\t * e.oclIsKindOf(MapEntryLink) and\n\t\t\t\t * e.oclAsType(MapEntryLink).valueTarget = self\n\t\t\t\t \052/\n\t\t\t\t/*@Caught\052/ /*@NonNull\052/ &lt;%java.lang.Object%&gt; CAUGHT_and_4;\n\t\t\t\ttry {\n\t\t\t\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.Class%&gt; TYP_mlstorypatterns_c_c_MapEntryLink = idResolver.getClass(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.CLSSid_MapEntryLink, null);\n\t\t\t\t\tfinal /*@NonInvalid\052/ boolean oclIsKindOf_2 = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclIsKindOfOperation%&gt;.INSTANCE.evaluate(executor, e_2, TYP_mlstorypatterns_c_c_MapEntryLink).booleanValue();\n\t\t\t\t\t/*@Thrown\052/ boolean and_4;\n\t\t\t\t\tif (oclIsKindOf_2) {\n\t\t\t\t\t\tfinal /*@Thrown\052/ &lt;%de.mdelab.mlstorypatterns.MapEntryLink%&gt; oclAsType_4 = &lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState((&lt;%de.mdelab.mlstorypatterns.MapEntryLink%&gt;)&lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyOclAsTypeOperation%&gt;.INSTANCE.evaluate(executor, e_2, TYP_mlstorypatterns_c_c_MapEntryLink));\n\t\t\t\t\t\tfinal /*@Thrown\052/ &lt;%de.mdelab.mlstorypatterns.AbstractStoryPatternObject%&gt; valueTarget = oclAsType_4.getValueTarget();\n\t\t\t\t\t\tfinal /*@Thrown\052/ boolean eq_0 = this.equals(valueTarget);\n\t\t\t\t\t\tand_4 = eq_0;\n\t\t\t\t\t}\n\t\t\t\t\telse {\n\t\t\t\t\t\tand_4 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t\t\t\t\t}\n\t\t\t\t\tCAUGHT_and_4 = and_4;\n\t\t\t\t}\n\t\t\t\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\t\t\t\tCAUGHT_and_4 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t\t\t\t}\n\t\t\t\t//\n\t\t\t\tif (CAUGHT_and_4 == &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE) {\t\t\t\t\t// Normal successful body evaluation result\n\t\t\t\t\texists_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t\t\t\t\tbreak;\t\t\t\t\t\t\t\t\t\t\t\t\t\t// Stop immediately\n\t\t\t\t}\n\t\t\t\telse if (CAUGHT_and_4 == &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE) {\t\t\t\t// Normal unsuccessful body evaluation result\n\t\t\t\t\t;\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t// Carry on\n\t\t\t\t}\n\t\t\t\telse if (CAUGHT_and_4 instanceof &lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;) {\t\t// Abnormal exception evaluation result\n\t\t\t\t\taccumulator_1 = CAUGHT_and_4;\t\t\t\t\t\t\t\t\t// Cache an exception failure\n\t\t\t\t}\n\t\t\t\telse {\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t// Impossible badly typed result\n\t\t\t\t\taccumulator_1 = new &lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;(&lt;%org.eclipse.ocl.pivot.messages.PivotMessages%&gt;.NonBooleanBody, \"exists\");\n\t\t\t\t}\n\t\t\t}\n\t\t\tCAUGHT_exists_1 = exists_1;\n\t\t}\n\t\tcatch (&lt;%java.lang.Exception%&gt; e) {\n\t\t\tCAUGHT_exists_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createInvalidValue(e);\n\t\t}\n\t\tfinal /*@Thrown\052/ &lt;%java.lang.Boolean%&gt; or_2 = &lt;%org.eclipse.ocl.pivot.library.logical.BooleanOrOperation%&gt;.INSTANCE.evaluate(CAUGHT_or_1, CAUGHT_exists_1);\n\t\timplies = or_2;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\tif (implies == null) {\n\t\tthrow new &lt;%org.eclipse.ocl.pivot.values.InvalidValueException%&gt;(\"Null if condition\");\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Story_32_pattern_32_object_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_must_32_be_32_reacheable_32_from_32_another_32_object);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectIncomingLink, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean StoryPatternObjectIncomingLink(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternObjectCreatedUnbound:\n *   let\n *     severity : Integer[1] = \'StoryPatternObject::StoryPatternObjectCreatedUnbound\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.modifier = ModifierEnum::CREATE implies self.bindingType = BindingTypeEnum::UNBOUND\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Created story pattern object \' +\n *               self.toString() + \' must be unbound.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternObject::StoryPatternObjectCreatedUnbound\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectCreatedUnbound);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier = this.getModifier();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_modifier == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_CREATE;\n\t/*@NonInvalid\052/ boolean implies;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.BindingTypeEnum%&gt; bindingType = this.getBindingType();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_bindingType = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_BindingTypeEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(bindingType.getName()));\n\t\tfinal /*@NonInvalid\052/ boolean eq_0 = BOXED_bindingType == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_UNBOUND;\n\t\timplies = eq_0;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Created_32_story_32_pattern_32_object_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_must_32_be_32_unbound);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectCreatedUnbound, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean StoryPatternObjectCreatedUnbound(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternObjectCreatedConstraints:\n *   let\n *     severity : Integer[1] = \'StoryPatternObject::StoryPatternObjectCreatedConstraints\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.modifier = ModifierEnum::CREATE and self.matchType = MatchTypeEnum::DEFAULT implies\n *             self.constraints-&gt;isEmpty()\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Created story pattern object \' +\n *               self.toString() + \' may not have constraints.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternObject::StoryPatternObjectCreatedConstraints\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectCreatedConstraints);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier = this.getModifier();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_modifier == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_CREATE;\n\t/*@NonInvalid\052/ boolean and;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.MatchTypeEnum%&gt; matchType = this.getMatchType();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_matchType = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_MatchTypeEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(matchType.getName()));\n\t\tfinal /*@NonInvalid\052/ boolean eq_0 = BOXED_matchType == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_DEFAULT;\n\t\tand = eq_0;\n\t}\n\telse {\n\t\tand = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.FALSE_VALUE;\n\t}\n\t/*@NonInvalid\052/ boolean implies;\n\tif (and) {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.util.List%&gt;&lt;&lt;%de.mdelab.mlexpressions.MLExpression%&gt;&gt; constraints = this.getConstraints();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.SetValue%&gt; BOXED_constraints = idResolver.createSetOfAll(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.SET_CLSSid_MLExpression, constraints);\n\t\tfinal /*@NonInvalid\052/ boolean isEmpty = &lt;%org.eclipse.ocl.pivot.library.collection.CollectionIsEmptyOperation%&gt;.INSTANCE.evaluate(BOXED_constraints).booleanValue();\n\t\timplies = isEmpty;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Created_32_story_32_pattern_32_object_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_may_32_not_32_have_32_constraints);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectCreatedConstraints, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean StoryPatternObjectCreatedConstraints(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternObjectDestroyed:\n *   let\n *     severity : Integer[1] = \'StoryPatternObject::StoryPatternObjectDestroyed\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.modifier = ModifierEnum::DESTROY implies\n *             self.attributeAssignments-&gt;isEmpty()\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Destroyed story pattern object \' +\n *               self.toString() + \' may not have attribute assignments.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternObject::StoryPatternObjectDestroyed\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.IdResolver%&gt; idResolver = executor.getIdResolver();\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectDestroyed);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.ModifierEnum%&gt; modifier = this.getModifier();\n\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_modifier = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_ModifierEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(modifier.getName()));\n\tfinal /*@NonInvalid\052/ boolean eq = BOXED_modifier == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_DESTROY;\n\t/*@NonInvalid\052/ boolean implies;\n\tif (eq) {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.util.List%&gt;&lt;&lt;%de.mdelab.mlstorypatterns.AttributeAssignment%&gt;&gt; attributeAssignments = this.getAttributeAssignments();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.SetValue%&gt; BOXED_attributeAssignments = idResolver.createSetOfAll(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.SET_CLSSid_AttributeAssignment, attributeAssignments);\n\t\tfinal /*@NonInvalid\052/ boolean isEmpty = &lt;%org.eclipse.ocl.pivot.library.collection.CollectionIsEmptyOperation%&gt;.INSTANCE.evaluate(BOXED_attributeAssignments).booleanValue();\n\t\timplies = isEmpty;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Destroyed_32_story_32_pattern_32_object_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_may_32_not_32_have_32_attribute_32_assignments);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectDestroyed, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean StoryPatternObjectDestroyed(DiagnosticChain diagnostics,
			Map<Object, Object> context);

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @model annotation="http://www.eclipse.org/emf/2002/GenModel body='/**\n *\n * inv StoryPatternObjectNACUnbound:\n *   let\n *     severity : Integer[1] = \'StoryPatternObject::StoryPatternObjectNACUnbound\'.getSeverity()\n *   in\n *     if severity &lt;= 0\n *     then true\n *     else\n *       let\n *         result : OclAny[1] = let\n *           status : Boolean[?] = if self.storyPattern.containingPattern &lt;&gt; null implies self.bindingType = BindingTypeEnum::UNBOUND\n *           then true\n *           else null\n *           endif\n *         in\n *           if status = true\n *           then true\n *           else\n *             Tuple{message = \'Story pattern object \' +\n *               self.toString() + \' in a NAC must be unbound.\', status = status\n *             }\n *           endif\n *       in\n *         \'StoryPatternObject::StoryPatternObjectNACUnbound\'.logDiagnostic(self, null, diagnostics, context, null, severity, result, 0)\n *     endif\n \052/\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.evaluation.Executor%&gt; executor = &lt;%org.eclipse.ocl.pivot.internal.utilities.PivotUtilInternal%&gt;.getExecutor(this);\nfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.IntegerValue%&gt; severity_0 = &lt;%org.eclipse.ocl.pivot.library.string.CGStringGetSeverityOperation%&gt;.INSTANCE.evaluate(executor, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectNACUnbound);\nfinal /*@NonInvalid\052/ boolean le = &lt;%org.eclipse.ocl.pivot.library.oclany.OclComparableLessThanEqualOperation%&gt;.INSTANCE.evaluate(executor, severity_0, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_3;\nif (le) {\n\tsymbol_3 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n}\nelse {\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPattern%&gt; storyPattern = this.getStoryPattern();\n\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.StoryPattern%&gt; containingPattern = storyPattern.getContainingPattern();\n\tfinal /*@NonInvalid\052/ boolean ne = containingPattern != null;\n\t/*@NonInvalid\052/ boolean implies;\n\tif (ne) {\n\t\tfinal /*@NonInvalid\052/ &lt;%de.mdelab.mlstorypatterns.BindingTypeEnum%&gt; bindingType = this.getBindingType();\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.ids.EnumerationLiteralId%&gt; BOXED_bindingType = &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ENUMid_BindingTypeEnum.getEnumerationLiteralId(&lt;%org.eclipse.ocl.pivot.utilities.ClassUtil%&gt;.nonNullState(bindingType.getName()));\n\t\tfinal /*@NonInvalid\052/ boolean eq = BOXED_bindingType == &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.ELITid_UNBOUND;\n\t\timplies = eq;\n\t}\n\telse {\n\t\timplies = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\t/*@NonInvalid\052/ &lt;%java.lang.Boolean%&gt; status;\n\tif (implies) {\n\t\tstatus = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tstatus = null;\n\t}\n\tfinal /*@NonInvalid\052/ boolean symbol_0 = status == Boolean.TRUE;\n\t/*@NonInvalid\052/ &lt;%java.lang.Object%&gt; symbol_2;\n\tif (symbol_0) {\n\t\tsymbol_2 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.TRUE_VALUE;\n\t}\n\telse {\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; toString = &lt;%org.eclipse.ocl.pivot.library.oclany.OclAnyToStringOperation%&gt;.INSTANCE.evaluate(this);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_Story_32_pattern_32_object_32, toString);\n\t\tfinal /*@NonInvalid\052/ &lt;%java.lang.String%&gt; sum_0 = &lt;%org.eclipse.ocl.pivot.library.string.StringConcatOperation%&gt;.INSTANCE.evaluate(sum, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR__32_in_32_a_32_NAC_32_must_32_be_32_unbound);\n\t\tfinal /*@NonInvalid\052/ &lt;%org.eclipse.ocl.pivot.values.TupleValue%&gt; symbol_1 = &lt;%org.eclipse.ocl.pivot.utilities.ValueUtil%&gt;.createTupleOfEach(&lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.TUPLid_, sum_0, status);\n\t\tsymbol_2 = symbol_1;\n\t}\n\tfinal /*@NonInvalid\052/ boolean logDiagnostic = &lt;%org.eclipse.ocl.pivot.library.string.CGStringLogDiagnosticOperation%&gt;.INSTANCE.evaluate(executor, &lt;%org.eclipse.ocl.pivot.ids.TypeId%&gt;.BOOLEAN, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.STR_StoryPatternObject_c_c_StoryPatternObjectNACUnbound, this, (Object)null, diagnostics, context, (Object)null, severity_0, symbol_2, &lt;%de.mdelab.mlstorypatterns.MlstorypatternsTables%&gt;.INT_0).booleanValue();\n\tsymbol_3 = logDiagnostic;\n}\nreturn Boolean.TRUE == symbol_3;'"
	 * @generated
	 */
	boolean StoryPatternObjectNACUnbound(DiagnosticChain diagnostics,
			Map<Object, Object> context);

} // StoryPatternObject
